(function(factory) {
	if (typeof module !== 'undefined' && typeof exports !== 'undefined' && this === exports) {
		module.exports = factory(require('vue'));
	} else {
		this.Vue.component('VueResizeSensor', factory(this.Vue));
	}
}).call(this, function(Vue) {

	return {
		render(createElement) {
			return(
				createElement(this.tag, [
					createElement('iframe', {
						style: {
							position: 'absolute',
							width: '100%',
							height: '100%',
							border: 'none',
							opacity: '0',
							pointerEvents: 'none',
						},
						on: {'~load': this.onLoad},
					}),
					...this.$slots.default,
				])
			);
		},

		props: {
			tag: {
				type: String,
				default: 'div',
			},
		},

		data() {
			return {width: 0, height: 0};
		},

		mounted() {
			this.onResize();
		},

		activated() {
			this.onResize();
		},

		computed: {
			resizeEventParams() {
				return {width: this.width, height: this.height};
			},
		},

		watch: {
			resizeEventParams(params) {
				this.$emit('resize', params);
			},
		},

		methods: {
			onLoad(event) {
				event.target.contentWindow.addEventListener('resize', this.onResize.bind(this));
			},

			onResize() {
				let width;
				let height;
				try {
					({width, height} = this.$el.getBoundingClientRect());
				} catch (error) {
					try {
						width = this.$el.offsetWidth;
						height = this.$el.offsetHeight;
					} catch (error) {
						width = 0;
						height = 0;
					}
				}
				this.width = width;
				this.height = height;
			},
		},
	};

});